@@ -6,6 +6,8 @@ from lightwood.analysis.explain import explain
 from lightwood.analysis.base import BaseAnalysisBlock
 from lightwood.analysis.nc.calibrate import ICP
 from lightwood.analysis.helpers.acc_stats import AccStats
+from lightwood.analysis.helpers.conf_stats import ConfStats
+from lightwood.analysis.nn_conf.temp_scale import TempScaler
 from lightwood.analysis.helpers.feature_importance import GlobalFeatureImportance
 
 try:
@@ -14,5 +16,5 @@ except Exception:
     ShapleyValues = None
 
 
-__all__ = ['model_analyzer', 'explain', 'ICP', 'AccStats',
-           'GlobalFeatureImportance', 'BaseAnalysisBlock', 'ShapleyValues']
+__all__ = ['model_analyzer', 'explain', 'BaseAnalysisBlock', 'TempScaler',
+           'ICP', 'AccStats', 'ConfStats', 'GlobalFeatureImportance', 'ShapleyValues']
