@@ -220,27 +220,46 @@ def generate_json_ai(
     ):
         is_target_predicting_encoder = True
 
+    submodels = []
     if is_target_predicting_encoder:
-        submodels = [
-            {
-                "module": "Unit",
-                "args": {
-                    "target_encoder": "$encoders[self.target]",
-                    "stop_after": "$problem_definition.seconds_per_mixer",
-                },
-            }
-        ]
+        submodels.extend(
+            [
+                {
+                    "module": "Unit",
+                    "args": {
+                        "target_encoder": "$encoders[self.target]",
+                        "stop_after": "$problem_definition.seconds_per_mixer",
+                    },
+                }
+            ]
+        )
     else:
-        submodels = [
-            {
-                "module": "Neural",
-                "args": {
-                    "fit_on_dev": True,
-                    "stop_after": "$problem_definition.seconds_per_mixer",
-                    "search_hyperparameters": True,
-                },
-            }
-        ]
+        if not tss.is_timeseries:
+            submodels.extend(
+                [
+                    {
+                        "module": "Neural",
+                        "args": {
+                            "fit_on_dev": True,
+                            "stop_after": "$problem_definition.seconds_per_mixer",
+                            "search_hyperparameters": True,
+                        },
+                    }
+                ]
+            )
+        else:
+            submodels.extend(
+                [
+                    {
+                        "module": "NeuralTs",
+                        "args": {
+                            "fit_on_dev": True,
+                            "stop_after": "$problem_definition.seconds_per_mixer",
+                            "search_hyperparameters": True,
+                        },
+                    }
+                ]
+            )
 
         if (not tss.is_timeseries or tss.horizon == 1) and dtype_dict[target] not in (dtype.num_array, dtype.cat_array):
             submodels.extend(
@@ -268,7 +287,8 @@ def generate_json_ai(
                         "args": {
                             "fit_on_dev": True,
                             "stop_after": "$problem_definition.seconds_per_mixer",
-                            "horizon": "$problem_definition.timeseries_settings.horizon",
+                            "ts_analysis": "$ts_analysis",
+                            "tss": "$problem_definition.timeseries_settings",
                         },
                     }
                 ]
@@ -494,13 +514,12 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
     is_ts = tss.is_timeseries
 
     # Add implicit arguments
-    # @TODO: Consider removing once we have a proper editor in studio
     mixers = json_ai.model['args']['submodels']
     for i in range(len(mixers)):
         if mixers[i]["module"] == "Unit":
             pass
 
-        elif mixers[i]["module"] == "Neural":
+        elif mixers[i]["module"] in ("Neural", "NeuralTs"):
             mixers[i]["args"]["target_encoder"] = mixers[i]["args"].get(
                 "target_encoder", "$encoders[self.target]"
             )
@@ -508,15 +527,17 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
             mixers[i]["args"]["dtype_dict"] = mixers[i]["args"].get(
                 "dtype_dict", "$dtype_dict"
             )
-            mixers[i]["args"]["timeseries_settings"] = mixers[i]["args"].get(
-                "timeseries_settings", "$problem_definition.timeseries_settings"
-            )
             mixers[i]["args"]["net"] = mixers[i]["args"].get(
                 "net",
                 '"DefaultNet"'
                 if not tss.is_timeseries or not tss.use_previous_target
                 else '"ArNet"',
             )
+            if mixers[i]["module"] == "NeuralTs":
+                mixers[i]["args"]["timeseries_settings"] = mixers[i]["args"].get(
+                    "timeseries_settings", "$problem_definition.timeseries_settings"
+                )
+                mixers[i]["args"]["ts_analysis"] = mixers[i]["args"].get("ts_analysis", "$ts_analysis")
 
         elif mixers[i]["module"] == "LightGBM":
             mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
@@ -551,8 +572,17 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
             mixers[i]["args"]["target_encoder"] = mixers[i]["args"].get(
                 "target_encoder", "$encoders[self.target]"
             )
-            if "horizon" not in mixers[i]["args"]:
-                mixers[i]["args"]["horizon"] = "$problem_definition.timeseries_settings.horizon"
+            mixers[i]["args"]["tss"] = mixers[i]["args"].get("tss", "$problem_definition.timeseries_settings")
+            mixers[i]["args"]["ts_analysis"] = mixers[i]["args"].get("ts_analysis", "$ts_analysis")
+            mixers[i]["args"]["fit_on_dev"] = mixers[i]["args"].get("fit_on_dev", "True")
+
+        elif mixers[i]["module"] == "NHitsMixer":
+            mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
+            mixers[i]["args"]["horizon"] = "$problem_definition.timeseries_settings.horizon"
+            mixers[i]["args"]["ts_analysis"] = mixers[i]["args"].get(
+                "ts_analysis", "$ts_analysis"
+            )
+            problem_definition.fit_on_all = False  # takes too long otherwise
 
         elif mixers[i]["module"] in ("SkTime", "ProphetMixer"):
             mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
@@ -666,6 +696,7 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
                 "dtype_dict": "$dtype_dict",
                 "target": "$target",
                 "mode": "$mode",
+                "ts_analysis": "$ts_analysis"
             },
         },
         "timeseries_analyzer": {
@@ -807,11 +838,6 @@ data = {call(json_ai.cleaner)}
 
 # Time-series blocks
 {ts_transform_code}
-"""
-    if ts_analyze_code is not None:
-        clean_body += f"""
-if self.mode != 'predict':
-{align(ts_analyze_code,1)}
 """
 
     clean_body += '\nreturn data'
@@ -835,12 +861,19 @@ return train_test_data
     # Prepare features Body
     # ----------------- #
 
-    prepare_body = f"""
+    prepare_body = """
 self.mode = 'train'
 
 if self.statistical_analysis is None:
     raise Exception("Please run analyze_data first")
+"""
+    if ts_analyze_code is not None:
+        prepare_body += f"""
+if self.mode != 'predict':
+    {align(ts_analyze_code, 1)}
+"""
 
+    prepare_body += f"""
 # Column to encoder mapping
 self.encoders = {inline_dict(encoder_dict)}
 
@@ -1133,6 +1166,7 @@ class Predictor(PredictorInterface):
 
         # Initial stats analysis
         self.statistical_analysis = None
+        self.ts_analysis = None
         self.runtime_log = dict()
 
     @timed
