@@ -1,19 +1,19 @@
-import copy
-import datetime
-import dateutil
+from typing import Dict
+from functools import partial
+import multiprocessing as mp
+
 import numpy as np
 import pandas as pd
-import multiprocessing as mp
 from lightwood.helpers.parallelism import get_nr_procs
-from functools import partial
-from typing import Dict
+from lightwood.helpers.ts import get_ts_groups, get_delta, get_group_matches
+
+from lightwood.api import dtype
 from lightwood.api.types import TimeseriesSettings
 from lightwood.helpers.log import log
-from lightwood.api import dtype
 
 
 def transform_timeseries(
-        data: pd.DataFrame, dtype_dict: Dict[str, str],
+        data: pd.DataFrame, dtype_dict: Dict[str, str], ts_analysis: dict,
         timeseries_settings: TimeseriesSettings, target: str, mode: str) -> pd.DataFrame:
     """
     Block that transforms the dataframe of a time series task to a convenient format for use in posterior phases like model training.
@@ -27,6 +27,7 @@ def transform_timeseries(
     
     :param data: Dataframe with data to transform.
     :param dtype_dict: Dictionary with the types of each column.
+    :param ts_analysis: dictionary with various insights into each series passed as training input.
     :param timeseries_settings: A `TimeseriesSettings` object.
     :param target: The name of the target column to forecast.
     :param mode: Either "train" or "predict", depending on what phase is calling this procedure.
@@ -35,7 +36,6 @@ def transform_timeseries(
     """  # noqa
 
     tss = timeseries_settings
-    original_df = copy.deepcopy(data)
     gb_arr = tss.group_by if tss.group_by is not None else []
     ob_arr = tss.order_by
     window = tss.window
@@ -47,6 +47,26 @@ def transform_timeseries(
         if hcol not in data.columns or data[hcol].isna().any():
             raise Exception(f"Cannot transform. Missing values in historical column {hcol}.")
 
+    # infer frequency with get_delta
+    oby_col = tss.order_by[0]
+    groups = get_ts_groups(data, tss)
+    if not ts_analysis:
+        _, _, freqs = get_delta(data, dtype_dict, groups, tss)
+    else:
+        freqs = ts_analysis['sample_freqs']
+
+    # pass seconds to timestamps according to each group's inferred freq, and force this freq on index
+    subsets = []
+    for group in groups:
+        if (tss.group_by and group != '__default') or not tss.group_by:
+            idxs, subset = get_group_matches(data, group, tss.group_by)
+
+            index = pd.to_datetime(subset[oby_col], unit='s')
+            subset.index = pd.date_range(start=index.iloc[0], freq=freqs[group], periods=len(subset))
+            subset['__mdb_inferred_freq'] = subset.index.freq   # sets constant column because pd.concat forgets freq (see: https://github.com/pandas-dev/pandas/issues/3232)  # noqa
+            subsets.append(subset)
+    original_df = pd.concat(subsets).sort_values(by='__mdb_original_index')
+
     if '__mdb_forecast_offset' in original_df.columns:
         """ This special column can be either None or an integer. If this column is passed, then the TS transformation will react to the values within:
 
@@ -62,7 +82,6 @@ def transform_timeseries(
         else:
             offset = 0
         infer_mode = offset_available and offset == 1
-        original_df = original_df.reset_index(drop=True) if infer_mode else original_df
     else:
         offset_available = False
         offset = 0
@@ -86,30 +105,6 @@ def transform_timeseries(
         if dtype_dict[col] in (dtype.date, dtype.integer, dtype.float):
             secondary_type_dict[col] = dtype_dict[col]
 
-    # Convert order_by columns to numbers (note, rows are references to mutable rows in `original_df`)
-    for i, row in original_df.iterrows():
-        for col in ob_arr:
-            # @TODO: Remove if the TS encoder can handle `None`
-            if row[col] is None or pd.isna(row[col]):
-                original_df.at[i, col] = 0.0
-            else:
-                if dtype_dict[col] == dtype.date:
-                    try:
-                        row[col] = dateutil.parser.parse(
-                            row[col],
-                            **{}
-                        )
-                    except (TypeError, ValueError):
-                        pass
-
-                if isinstance(row[col], datetime.datetime):
-                    row[col] = row[col].timestamp()
-
-                try:
-                    row[col] = float(row[col])
-                except ValueError:
-                    raise ValueError(f'Failed to order based on column: "{col}" due to faulty value: {row[col]}')
-
     for oby in tss.order_by:
         original_df[f'__mdb_original_{oby}'] = original_df[oby]
 
@@ -124,13 +119,11 @@ def transform_timeseries(
         group_lengths.append(len(original_df))
 
     n_groups = len(df_arr)
-    last_index = original_df['original_index'].max()
     for i, subdf in enumerate(df_arr):
         if '__mdb_forecast_offset' in subdf.columns and mode == 'predict':
             if infer_mode:
-                df_arr[i] = _ts_infer_next_row(subdf, ob_arr, last_index)
+                df_arr[i] = _ts_infer_next_row(subdf, ob_arr)
                 make_preds = [False for _ in range(max(0, len(df_arr[i]) - 1))] + [True]
-                last_index += 1
             elif offset_available:
                 # truncate to forecast up until some len(df) + offset (which is <= 0)
                 new_index = df_arr[i].index[:len(df_arr[i].index) + offset]
@@ -223,27 +216,31 @@ def transform_timeseries(
     return combined_df
 
 
-def _ts_infer_next_row(df: pd.DataFrame, ob: str, last_index: int) -> pd.DataFrame:
+def _ts_infer_next_row(df: pd.DataFrame, ob: str) -> pd.DataFrame:
     """
     Adds an inferred next row for streaming mode purposes.
 
     :param df: dataframe from which next row is inferred.
     :param ob: `order_by` column.
-    :param last_index: index number of the latest row in `df`.
 
     :return: Modified `df` with the inferred row appended to it.
     """
+    original_index = df.index.copy()
+    start = original_index.min()
+    new_index = pd.date_range(start=start, periods=len(original_index) + 1, freq=df['__mdb_inferred_freq'].iloc[0])
     last_row = df.iloc[[-1]].copy()
+    last_row['__mdb_ts_inferred'] = True
+
     if df.shape[0] > 1:
         butlast_row = df.iloc[[-2]]
         delta = (last_row[ob].values - butlast_row[ob].values).flatten()[0]
     else:
         delta = 1
-    last_row.original_index = None
-    last_row.index = [last_index + 1]
-    last_row['__mdb_ts_inferred'] = True
+
     last_row[ob] += delta
-    return df.append(last_row)
+    new_df = df.append(last_row)
+    new_df.index = pd.DatetimeIndex(new_index)
+    return new_df
 
 
 def _make_pred(row) -> bool:
@@ -277,9 +274,9 @@ def _ts_order_col_to_cell_lists(df: pd.DataFrame, order_cols: list) -> pd.DataFr
     :return: Dataframe with all `order_cols` modified so that their values are cells, e.g. `1` -> `[1]`
     """
     for order_col in order_cols:
-        for ii in range(len(df)):
-            label = df.index.values[ii]
-            df.at[label, order_col] = [df.at[label, order_col]]
+        col_idx = df.columns.tolist().index(order_col)
+        for i in range(len(df)):
+            df.iat[i, col_idx] = [df.iat[i, col_idx]]
     return df
 
 
